==> canmatrix-0.1.tar.gz: canmatrix-0.1/canmatrix/exportall.py <==
#!/usr/bin/env python
from __future__ import print_function
from __future__ import absolute_import
from .exportdbc import *
from .exportdbf import *
from .exportsym import *
from .exportJson import *

try:
    from .exportarxml import *
except:
    print("no arxml-export-support, some dependencys missing...  (probably lxml)")

try:
    from .exportkcd import *
except:
    print("no kcd-export-support, some dependencys missing... ")


try:
    from .exportxls import *
except:
    print("no xls-export-support, some dependencys missing... ")
try:
    from .exportxlsx import *
except:
    print("no xlsx-export-support, some dependencys missing... ")
try:
    from .exportyaml import *
except:
    print("no yaml-export-support, some dependencys missing ... (probably yaml) ")



#Copyright (c) 2013, Eduard Broecker
#All rights reserved.
#
#Redistribution and use in source and binary forms, with or without modification, are permitted provided that
# the following conditions are met:
#
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the
#    following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
#    following disclaimer in the documentation and/or other materials provided with the distribution.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
#WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
#PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
#DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
#DAMAGE.

==> canmatrix-0.3.tar.gz: canmatrix-0.3/canmatrix/exportall.py <==
#!/usr/bin/env python
from __future__ import print_function
from __future__ import absolute_import

import logging
logger = logging.getLogger('root')

from .exportdbc import *
from .exportdbf import *
from .exportsym import *
from .exportJson import *
from .exportcsv import *


try:
    from .exportarxml import *
except:
    logger.warn("no arxml-export-support, some dependencies missing... try pip install lxml")

try:
    from .exportkcd import *
except:
    logger.warn("no kcd-export-support, some dependenies missing...  try pip install lxml")

try:
    from .exportsym import *
except:
    logger.warn("no sym-export-support, some dependencies missing... ")

try:
    from .exportxls import *
except:
    logger.warn("no xls-export-support, some dependencies missing...  try pip install xlwt")

try:
    from .exportxlsx import *
except:
    logger.warn("no xlsx-export-support, some dependencies missing...  try pip install xlswriter")

try:
    from .exportyaml import *
except:
    logger.warn("no yaml-export-support, some dependencies missing ...  try pip install pyyaml ")

try:
    from .exportxlsx import *
except:
    logger.warn("no xlsx-export-support, some dependencies missing... ")

try:
    from .exportyaml import *
except:
    logger.warn("no yaml-export-support, some dependencies missing ... (probably yaml) ")



#Copyright (c) 2013, Eduard Broecker
#All rights reserved.
#
#Redistribution and use in source and binary forms, with or without modification, are permitted provided that
# the following conditions are met:
#
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the
#    following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
#    following disclaimer in the documentation and/or other materials provided with the distribution.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
#WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
#PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
#DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
#DAMAGE.
